==> haskell-http-conduit-2.1.8-31-armv7h.pkg.tar.xz: usr/share/haskell/haskell-http-conduit/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-conduit
version: 2.1.8
id: http-conduit-2.1.8-288436503dec7c7ed70373ac0e4730a6
key: httpc_CMwafdzv6hZ7PgczRI0cRM
license: BSD3
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/book/http-conduit
synopsis: HTTP client package with conduit interface and HTTPS support.
description:
    This package uses conduit for parsing the actual contents of the HTTP connection. It also provides higher-level functions which allow you to avoid directly dealing with streaming data. See <http://www.yesodweb.com/book/http-conduit> for more information.
    .
    The @Network.HTTP.Conduit.Browser@ module has been moved to <http://hackage.haskell.org/package/http-conduit-browser/>
category: Web, Conduit
author: Michael Snoyman <michael@snoyman.com>
exposed: True
exposed-modules:
    Network.HTTP.Conduit Network.HTTP.Client.Conduit
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/http-conduit-2.1.8
library-dirs: /usr/lib/ghc-7.10.3/site-local/http-conduit-2.1.8
data-dir: /usr/share/arm-linux-ghc-7.10.3/http-conduit-2.1.8
hs-libraries: HShttp-conduit-2.1.8-CMwafdzv6hZ7PgczRI0cRM
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    conduit-1.2.6.4-0dfd87f475e845002478c37d3a30df1e
    http-client-0.4.27-649349307b7fbc2da7ba4e3fdfb27d3d
    http-client-tls-0.2.2-f98f7df0478363eb3e20cd852c79aa5a
    http-types-0.9-d392878af9c5e1b1993961dc71a9e177
    lifted-base-0.2.3.6-26b5b3c50c56a653ba3c5b8bce492107
    monad-control-1.0.0.5-237b0aabd7893e5e3f4b9224e05c849c
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    resourcet-1.1.7.3-3e7ca03abacc332d28328c69bbd74cd4
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
haddock-interfaces: /usr/share/doc/haskell-http-conduit/html/http-conduit.haddock
haddock-html: /usr/share/doc/haskell-http-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-conduit-2.1.8-34-armv7h.pkg.tar.xz: usr/share/haskell/haskell-http-conduit/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-conduit
version: 2.1.8
id: http-conduit-2.1.8-0cd87eafc953cbe4f675bdf50a2df8e2
key: httpc_5wx2pJbtl6n94Ap9qdoyx2
license: BSD3
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/book/http-conduit
synopsis: HTTP client package with conduit interface and HTTPS support.
description:
    This package uses conduit for parsing the actual contents of the HTTP connection. It also provides higher-level functions which allow you to avoid directly dealing with streaming data. See <http://www.yesodweb.com/book/http-conduit> for more information.
    .
    The @Network.HTTP.Conduit.Browser@ module has been moved to <http://hackage.haskell.org/package/http-conduit-browser/>
category: Web, Conduit
author: Michael Snoyman <michael@snoyman.com>
exposed: True
exposed-modules:
    Network.HTTP.Conduit Network.HTTP.Client.Conduit
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/http-conduit-2.1.8
library-dirs: /usr/lib/ghc-7.10.3/site-local/http-conduit-2.1.8
data-dir: /usr/share/arm-linux-ghc-7.10.3/http-conduit-2.1.8
hs-libraries: HShttp-conduit-2.1.8-5wx2pJbtl6n94Ap9qdoyx2
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    conduit-1.2.6.4-0dfd87f475e845002478c37d3a30df1e
    http-client-0.4.27-1cd31210c8ec4a6e0b4cc467bd24f592
    http-client-tls-0.2.2-05f6aae0a8612df864dc61b6b7405a00
    http-types-0.9-a274b17bf4f057225e6c0af6d57f03ec
    lifted-base-0.2.3.6-26b5b3c50c56a653ba3c5b8bce492107
    monad-control-1.0.0.5-237b0aabd7893e5e3f4b9224e05c849c
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    resourcet-1.1.7.3-3e7ca03abacc332d28328c69bbd74cd4
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
haddock-interfaces: /usr/share/doc/haskell-http-conduit/html/http-conduit.haddock
haddock-html: /usr/share/doc/haskell-http-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
